@@ -1,3 +1,15 @@
+#  Licensed under the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License. You may obtain
+#  a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#  License for the specific language governing permissions and limitations
+#  under the License.
+
 """Application base class for displaying data.
 """
 import abc
@@ -6,11 +18,11 @@ from itertools import compress
 import six
 import stevedore
 
-from .command import Command
+from . import command
 
 
 @six.add_metaclass(abc.ABCMeta)
-class DisplayCommandBase(Command):
+class DisplayCommandBase(command.Command):
     """Command base class for displaying data about a single object.
     """
 
