@@ -1,4 +1,16 @@
 #!/usr/bin/env python
+#
+#  Licensed under the Apache License, Version 2.0 (the "License"); you may
+#  not use this file except in compliance with the License. You may obtain
+#  a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#  License for the specific language governing permissions and limitations
+#  under the License.
 
 import mock
 from six import StringIO
@@ -6,6 +18,7 @@ import os
 import argparse
 
 from cliff.formatters import table
+from cliff.tests import test_columns
 
 
 class args(object):
@@ -66,6 +79,7 @@ def test_table_formatter(tw):
     assert expected == _table_tester_helper(c, d)
 
 
+# Multi-line output when width is restricted to 42 columns
 expected_ml_val = '''\
 +-------+--------------------------------+
 | Field | Value                          |
@@ -79,6 +93,39 @@ expected_ml_val = '''\
 +-------+--------------------------------+
 '''
 
+# Multi-line output when width is restricted to 80 columns
+expected_ml_80_val = '''\
++-------+----------------------------------------------------------------------+
+| Field | Value                                                                |
++-------+----------------------------------------------------------------------+
+| a     | A                                                                    |
+| b     | B                                                                    |
+| c     | C                                                                    |
+| d     | dddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddd |
+|       | ddddddddd                                                            |
++-------+----------------------------------------------------------------------+
+'''  # noqa
+
+# Single-line output, for when no line length restriction apply
+expected_sl_val = '''\
++-------+-------------------------------------------------------------------------------+
+| Field | Value                                                                         |
++-------+-------------------------------------------------------------------------------+
+| a     | A                                                                             |
+| b     | B                                                                             |
+| c     | C                                                                             |
+| d     | ddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddddd |
++-------+-------------------------------------------------------------------------------+
+'''  # noqa
+
+
+@mock.patch('cliff.utils.terminal_width')
+def test_table_formatter_no_cli_param(tw):
+    tw.return_value = 80
+    c = ('a', 'b', 'c', 'd')
+    d = ('A', 'B', 'C', 'd' * 77)
+    assert expected_ml_80_val == _table_tester_helper(c, d, extra_args=args())
+
 
 @mock.patch('cliff.utils.terminal_width')
 def test_table_formatter_cli_param(tw):
@@ -89,6 +136,24 @@ def test_table_formatter_cli_param(tw):
             _table_tester_helper(c, d, extra_args=['--max-width', '42']))
 
 
+@mock.patch('cliff.utils.terminal_width')
+def test_table_formatter_no_cli_param_unlimited_tw(tw):
+    tw.return_value = 0
+    c = ('a', 'b', 'c', 'd')
+    d = ('A', 'B', 'C', 'd' * 77)
+    # output should not be wrapped to multiple lines
+    assert expected_sl_val == _table_tester_helper(c, d, extra_args=args())
+
+
+@mock.patch('cliff.utils.terminal_width')
+def test_table_formatter_cli_param_unlimited_tw(tw):
+    tw.return_value = 0
+    c = ('a', 'b', 'c', 'd')
+    d = ('A', 'B', 'C', 'd' * 77)
+    assert (expected_ml_val ==
+            _table_tester_helper(c, d, extra_args=['--max-width', '42']))
+
+
 @mock.patch('cliff.utils.terminal_width')
 @mock.patch.dict(os.environ, {'CLIFF_MAX_TERM_WIDTH': '666'})
 def test_table_formatter_cli_param_envvar_big(tw):
@@ -185,6 +250,24 @@ def test_table_list_formatter(tw):
     assert expected == _table_tester_helper(c, data)
 
 
+@mock.patch('cliff.utils.terminal_width')
+def test_table_formatter_formattable_column(tw):
+    tw.return_value = 0
+    c = ('a', 'b', 'c', 'd')
+    d = ('A', 'B', 'C', test_columns.FauxColumn(['the', 'value']))
+    expected = '''\
++-------+---------------------------------------------+
+| Field | Value                                       |
++-------+---------------------------------------------+
+| a     | A                                           |
+| b     | B                                           |
+| c     | C                                           |
+| d     | I made this string myself: ['the', 'value'] |
++-------+---------------------------------------------+
+'''
+    assert expected == _table_tester_helper(c, d)
+
+
 _col_names = ('one', 'two', 'three')
 _col_data = [(
     'one one one one one',
@@ -249,6 +332,22 @@ _expected_mv = {
 }
 
 
+@mock.patch('cliff.utils.terminal_width')
+def test_table_list_formatter_formattable_column(tw):
+    tw.return_value = 80
+    c = ('a', 'b', 'c')
+    d1 = ('A', 'B', test_columns.FauxColumn(['the', 'value']))
+    data = [d1]
+    expected = '''\
++---+---+---------------------------------------------+
+| a | b | c                                           |
++---+---+---------------------------------------------+
+| A | B | I made this string myself: ['the', 'value'] |
++---+---+---------------------------------------------+
+'''
+    assert expected == _table_tester_helper(c, data)
+
+
 @mock.patch('cliff.utils.terminal_width')
 def test_table_list_formatter_max_width(tw):
     # no resize
